@@ -43,7 +43,7 @@ from mo_json import INTEGER
 from mo_kwargs import override
 from mo_logs import Log, Except
 from mo_math.randoms import Random
-from mo_sql import (
+from jx_bigquery.sql import (
     ConcatSQL,
     SQL,
     SQL_SELECT,
@@ -491,6 +491,7 @@ class Table(BaseFacts):
                 "Request payload size exceeds the limit" in e
                 or "An existing connection was forcibly closed by the remote host" in e
                 or "Your client has issued a malformed or illegal request." in e
+                or "BrokenPipeError(32, 'Broken pipe')" in e
             ):
                 # TRY A SMALLER BATCH
                 cut = len(rows) // 2
